@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.942'; # TRIAL
+$Email::MIME::VERSION = '1.943'; # TRIAL
 use Email::Simple 2.212; # nth header value
 use parent qw(Email::Simple);
 
@@ -61,7 +61,11 @@ use Scalar::Util qw(reftype weaken);
 #pod   );
 #pod
 #pod   my $email = Email::MIME->create(
-#pod       header_str => [ From => 'casey@geeknest.com' ],
+#pod       header_str => [
+#pod           From => 'casey@geeknest.com',
+#pod           To => [ 'user1@host.com', 'Name <user2@host.com>' ],
+#pod           Cc => Email::Address::XS->new("Display Name \N{U+1F600}", 'user@example.com'),
+#pod       ],
 #pod       parts      => [ @parts ],
 #pod   );
 #pod
@@ -143,11 +147,19 @@ sub new {
 #pod headers pairs to include in the message. The value for each pair is expected to
 #pod be a text string that will be MIME-encoded as needed.  Alternatively it can be
 #pod an object with C<as_mime_string> method which implements conversion of that
-#pod object to MIME-encoded string.  That object method is called with two input
-#pod parameters: charset and length of header name and should return MIME-encoded
-#pod representation of the object.  A similar C<header>
-#pod parameter can be provided in addition to or instead of C<header_str>.  Its
-#pod values will be used verbatim.
+#pod object to MIME-encoded string.  That object method is called with two named
+#pod input parameters: C<charset> and C<header_name_length>.  It should return
+#pod MIME-encoded representation of the object.
+#pod
+#pod In case header name is registered in C<%Email::MIME::Header::header_to_class_map>
+#pod hash then registered class is used for conversion from Unicode string to 8bit
+#pod MIME encoding.  Value can be either string or array reference to strings.
+#pod Object is constructed via method C<from_string> with string value (or values
+#pod in case of array reference) and converted to MIME-encoded string via
+#pod C<as_mime_string> method.
+#pod
+#pod A similar C<header> parameter can be provided in addition to or instead of
+#pod C<header_str>.  Its values will be used verbatim.
 #pod
 #pod C<attributes> is a hash of MIME attributes to assign to the part, and may
 #pod override portions of the header set in the C<header> parameter.
@@ -875,7 +887,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.942
+version 1.943
 
 =head1 SYNOPSIS
 
@@ -920,7 +932,11 @@ by all means keep reading.
   );
 
   my $email = Email::MIME->create(
-      header_str => [ From => 'casey@geeknest.com' ],
+      header_str => [
+          From => 'casey@geeknest.com',
+          To => [ 'user1@host.com', 'Name <user2@host.com>' ],
+          Cc => Email::Address::XS->new("Display Name \N{U+1F600}", 'user@example.com'),
+      ],
       parts      => [ @parts ],
   );
 
@@ -986,11 +1002,19 @@ This method creates a new MIME part. The C<header_str> parameter is a list of
 headers pairs to include in the message. The value for each pair is expected to
 be a text string that will be MIME-encoded as needed.  Alternatively it can be
 an object with C<as_mime_string> method which implements conversion of that
-object to MIME-encoded string.  That object method is called with two input
-parameters: charset and length of header name and should return MIME-encoded
-representation of the object.  A similar C<header>
-parameter can be provided in addition to or instead of C<header_str>.  Its
-values will be used verbatim.
+object to MIME-encoded string.  That object method is called with two named
+input parameters: C<charset> and C<header_name_length>.  It should return
+MIME-encoded representation of the object.
+
+In case header name is registered in C<%Email::MIME::Header::header_to_class_map>
+hash then registered class is used for conversion from Unicode string to 8bit
+MIME encoding.  Value can be either string or array reference to strings.
+Object is constructed via method C<from_string> with string value (or values
+in case of array reference) and converted to MIME-encoded string via
+C<as_mime_string> method.
+
+A similar C<header> parameter can be provided in addition to or instead of
+C<header_str>.  Its values will be used verbatim.
 
 C<attributes> is a hash of MIME attributes to assign to the part, and may
 override portions of the header set in the C<header> parameter.
