@@ -2,17 +2,26 @@ use strict;
 use warnings;
 package Email::MIME::Header;
 # ABSTRACT: the header of a MIME message
-$Email::MIME::Header::VERSION = '1.942'; # TRIAL
+$Email::MIME::Header::VERSION = '1.943'; # TRIAL
 use parent 'Email::Simple::Header';
 
 use Carp ();
 use Email::MIME::Encode;
 use Encode 1.9801;
+use Module::Runtime ();
 
 our @CARP_NOT;
 
 our %header_to_class_map;
 
+{
+  my @address_list_headers = qw(from sender reply-to to cc bcc);
+  push @address_list_headers, map { "resent-$_" } @address_list_headers;
+  push @address_list_headers, map { "downgraded-$_" } @address_list_headers; # RFC 5504
+  push @address_list_headers, qw(original-from disposition-notification-to); # RFC 5703 and RFC 3798
+  $header_to_class_map{$_} = 'Email::MIME::Header::AddressList' foreach @address_list_headers;
+}
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This object behaves like a standard Email::Simple header, with the following
@@ -87,7 +96,9 @@ sub header_as_obj {
 
   {
     local @CARP_NOT = qw(Email::MIME);
+    local $@;
     Carp::croak("No class for header '$name' was specified") unless defined $class;
+    Carp::croak("Cannot load package '$class' for header '$name': $@") unless eval { Module::Runtime::require_module($class) };
     Carp::croak("Class '$class' does not have method 'from_mime_string'") unless $class->can('from_mime_string');
   }
 
@@ -132,7 +143,7 @@ Email::MIME::Header - the header of a MIME message
 
 =head1 VERSION
 
-version 1.942
+version 1.943
 
 =head1 DESCRIPTION
 
